!include "cleaner.nsh"

!include MUI.nsh

Name "OJI"

OutFile "OJIkit.exe"

InstallDir "C:\OJI" # define the directory to install to

#Request application privileges for Windows Vista
RequestExecutionLevel admin

!define MUI_HEADERIMAGE
!define MUI_HEADERIMAGE_BITMAP "logo3.bmp"
!define MUI_BGCOLOR "6B9C0C"
!define MUI_ICON "IA.ico"

#SetCompress off
#SetCompress on
SetCompressor /SOLID zlib

Page custom checkIsAdmin "" ""
!insertmacro MUI_PAGE_COMPONENTS
!insertmacro MUI_PAGE_DIRECTORY
!insertmacro MUI_PAGE_INSTFILES

!insertmacro MUI_UNPAGE_CONFIRM
!insertmacro MUI_UNPAGE_INSTFILES

!insertmacro MUI_LANGUAGE "English"


# check if the current user has administrator rights
Function checkIsAdmin
	UserInfo::getAccountType # get user info.  The plugin puts the result in the stack
	Pop $0 # pop the result from the stack into $0
	StrCmp $0 "Admin" +3 # compare the result with the string "Admin" to see if the user is admin. If match, jump 3 lines down.

	# if there is not a match, print message and return
	MessageBox MB_OK "Utilizatorul nu este administrator. Este: $0"
	Abort
FunctionEnd


Section "Free Pascal" SEC01
	# the FreePascal Installer should take care of everything
	
	setOutPath $INSTDIR
	File "fpc-2.2.2.i386-win32.exe"
	ExecWait "$INSTDIR\fpc-2.2.2.i386-win32.exe /silent /DIR=FP"
	Delete "$INSTDIR\fpc-2.2.2.i386-win32.exe"
	# free pascal has it's own desktop shortcut
	
	# fix FP bug
	Delete "$INSTDIR\FP\bin\i386-win32\fp.cfg"
SectionEnd

Section "C/C++ IDEs" SEC02
	setOutPath $INSTDIR

	# MinGW Developer Studio
	File "MinGWStudioFullSetup-2_05.exe"
	ExecWait "MinGWStudioFullSetup-2_05.exe /S /D=$INSTDIR\MinGWStudio"
	delete "MinGWStudioFullSetup-2_05.exe"
	CreateShortCut "$DESKTOP\MinGW Developer Studio.lnk" "$INSTDIR\MinGWStudio\MinGWStudio.exe"

	# Code::Blocks
	File "codeblocks-8.02-setup.exe"
	ExecWait "codeblocks-8.02-setup.exe /S /D=$INSTDIR\CodeBlocks"
	Delete "codeblocks-8.02-setup.exe"
	CreateShortCut "$DESKTOP\CodeBlocks.lnk" "$INSTDIR\CodeBlocks\codeblocks.exe"

	# MASTER_PATH for the compiler used by Code::Blocks - same as path for compiler used by MinGW Developer Studio
	FileOpen $0 MasterPath.txt w
	FileWrite $0 $INSTDIR
	FileWrite $0 "\MinGWStudio\MinGW"
	FileClose $0

	File "default1.conf"
	File "default2.conf"

	# Join files to obtain default.conf. 
	ExecWait "cmd.exe /C copy /y default1.conf/b+MasterPath.txt/b default.tmp"
	ExecWait "cmd.exe /C copy /y default.tmp/b+default2.conf/b default.conf"

	# Put default.conf in the right path.		
	CopyFiles $INSTDIR\default.conf $INSTDIR\CodeBlocks

	Delete MasterPath.txt
	Delete default.tmp
	Delete default1.conf
	Delete default2.conf
	Delete default.conf
SectionEnd

Section "STL Documentation" SEC03
	setOutPath "$INSTDIR"
	File "STL_doc.tar.gz"
	File "untgz32.exe"
	ExecWait "$INSTDIR\untgz32.exe -y $INSTDIR\STL_doc.tar.gz"
	Delete "$INSTDIR\STL_doc.tar.gz"
	Delete "$INSTDIR\untgz32.exe"
	CreateShortCut "$DESKTOP\STL Doc.lnk" "$INSTDIR\STL_doc\index.html" "" "C:\WINDOWS\system32\SHELL32.dll" 175
SectionEnd

# default section
Section
	setOutPath $INSTDIR
	WriteUninstaller $INSTDIR\uninstall.exe # define uninstaller name
	
	# add/remove
	WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\OJI" \
		"DisplayName" "Pachet OJI"
	WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\OJI" \
		"UninstallString" "$INSTDIR\uninstall.exe"
SectionEnd

# Uninstall section is executed when uninstaller is run
Section "Uninstall"
	# Always delete uninstaller first
	Delete $INSTDIR\uninstaller.exe
	
	# uninstall FreePascal
	ExecWait "$INSTDIR\FP\unins000.exe /silent"

	# uninstall MinGW Studio
	ExecWait "$INSTDIR\MinGWStudio\uninstall.exe /S"

	# uninstall Code::Blocks
	ExecWait "$INSTDIR\CodeBlocks\uninstall.exe /S"

	# delete desktop shortcuts
	# free pascal has it's own desktop shortcut
	Delete "$DESKTOP\MinGW Developer Studio.lnk"
	Delete "$DESKTOP\STL Doc.lnk"
	Delete "$DESKTOP\CodeBlocks.lnk"
	
	# delete add/remove information
	DeleteRegKey HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\OJI"
	
	# delete everything inside the install dir
	!insertmacro RemoveFilesAndSubDirs "$INSTDIR"
	
	# delete install dir
	RMDir $INSTDIR 
SectionEnd